<?php

namespace Drupal\search_overrides\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\search_overrides\SearchOverrideReferencer;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\OpenModalDialogCommand;

/**
 * Provides listings of instances (with overrides) for a specified rule.
 */
class Manager extends ControllerBase {

  public function removeEntity($override, $entity, $field) {
    $message = $this->processRemoval($override, $entity, $field);
    // Redirect to a specified destination, if provided.
    $destination = Url::fromUserInput(\Drupal::destination()->get());
    if ($destination->getRouteName()) {
      // Valid internal path.
      $this->messenger()->addMessage($message);
      return $this->redirect($destination->getRouteName(), $destination->getRouteParameters());
    }
    $message = [
      '#type' => 'markup',
      '#markup' => $message,
    ];
    return $message;
  }

  public function removeEntityAjax($override, $entity, $field) {
    $message = $this->processRemoval($override, $entity, $field);
    // Update the table of overrides directly.
    $referencer = new SearchOverrideReferencer;
    $new_table = $referencer->EntityOverridesTable($entity);

    $renderer = \Drupal::service('renderer');
    $renderedTable = $renderer->render($new_table);

    $response = new AjaxResponse();
    $response->addCommand(new ReplaceCommand('#search-overrides--data', $renderedTable));
    // Show the dialog box.
    return $response;
  }

  private function processRemoval($override, $entity, $field) {
    $entities = $override->get($field)->getValue();
    foreach ($entities as $key => $temp_entity) {
      if ($temp_entity['target_id'] == $entity) {
        unset($entities[$key]);
      }
    }
    $override->set($field, $entities);
    $count = 0;
    foreach (['elnid','exnid'] as $count_field) {
      $count += count($override->get($count_field)->getValue());
    }
    if ($count) {
      $override->save();
      $message = $this->t('The search override was updated.');
    }
    else {
      $override->delete();
      $message = $this->t('The search override was removed.');
    }
    return $message;
  }

}
