<?php

namespace Drupal\search_overrides\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\search_overrides\Entity\SearchOverride;
use Drupal\search_overrides\SearchOverrideReferencer;

/**
 * Form controller for Search elevate edit forms.
 *
 * @ingroup search_api_solr_elevate_exclude
 */
class SearchOverrideAddByQueryForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'default_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['container'] = array(
      '#prefix' => '<div class="container-inline search-override--add-query-form">',
      '#suffix' => '</div>',
    );
    $eid = array_pop($form_state->getBuildInfo()['args']);
    $form['container']['query'] = [
      '#type' => 'textfield',
      '#placeholder' => $this->t('New keywords'),
      '#required' => TRUE,
      '#attributes' => [
        'class' => ['search-override--add-query-field'],
      ],
    ];

    $form['container']['eid'] = [
      '#type' => 'value',
      '#value' => $eid,
    ];

    $form['container']['field'] = [
      '#type' => 'select',
      '#options' => [
        'elnid' => $this->t('Promote'),
        'exnid' => $this->t('Exclude'),
      ],
    ];

    // Create the submit button.
    $form['container']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add'),
      '#ajax' => [
        'callback' => [$this, 'processInput'], //alternative notation
        'disable-refocus' => TRUE, // Or TRUE to prevent re-focusing on the triggering element.
        'event' => 'click',
        'wrapper' => 'search-overrides--data', // This element is updated with this AJAX callback.
        'effect' => 'fade',
        'progress' => [
          'type' => 'throbber',
          'message' => $this->t('Verifying entry...'),
        ],
        '#limit_validation_errors' => [
          ['submit'],
        ],
      ],
    ];

    return $form;
  }
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

  public function processInput(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    if (empty($values['query'])) {
      return NULL;
    }
    if (!$form_state->isValidationComplete()) {
      return $values;
    }

    $elQuery = \Drupal::entityQuery('search_override');
    $elevates = $elQuery->condition('query', $values['query'])->execute();
    if ($elevates) {
      $el_id = array_pop($elevates);
      $override = SearchOverride::load($el_id);
      $entities = $override->get($values['field'])->getValue();
      $entities[] = $values['eid'];
      $override->set($values['field'], $entities);
      $override->save();
    }
    else {
      // No existing override, so make one.
      $options = [
        $values['field'] => $values['eid'],
        'query' => $values['query'],
      ];
      $override = SearchOverride::create($options);
      $override->save();
    }

    // Update the table of overrides directly.
    $referencer = new SearchOverrideReferencer;
    $new_table = $referencer->EntityOverridesTable($values['eid']);

    $renderer = \Drupal::service('renderer');
    $renderedTable = $renderer->render($new_table);

    $response = new AjaxResponse();
    $response->addCommand(new ReplaceCommand('#search-overrides--data', $renderedTable));
    $response->addCommand(new InvokeCommand('.search-override--add-query-field', 'val', ['']));
    // Show the dialog box.
    return $response;
  }

}
